summaryrefslogtreecommitdiffstats
path: root/tdecore/kdemacros.h.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kdemacros.h.cmake')
-rw-r--r--tdecore/kdemacros.h.cmake25
1 files changed, 14 insertions, 11 deletions
diff --git a/tdecore/kdemacros.h.cmake b/tdecore/kdemacros.h.cmake
index 683538f9d..f48f518f6 100644
--- a/tdecore/kdemacros.h.cmake
+++ b/tdecore/kdemacros.h.cmake
@@ -25,7 +25,7 @@
#cmakedefine __KDE_HAVE_GCC_VISIBILITY 1
/**
* The KDE_NO_EXPORT macro marks the symbol of the given variable
* to be hidden. A hidden symbol is stripped during the linking step,
* so it can't be used from outside the resulting library, which is similar
* to static. However, static limits the visibility to the current
@@ -33,29 +33,32 @@
* units.
*
* \code
- * int KDE_NO_EXPORT foo;
- * int KDE_EXPORT bar;
+ * int TDE_NO_EXPORT foo;
+ * int TDE_EXPORT bar;
* \end
*/
#ifdef __KDE_HAVE_GCC_VISIBILITY
-#define KDE_NO_EXPORT __attribute__ ((visibility("hidden")))
-#define KDE_EXPORT __attribute__ ((visibility("default")))
+#define TDE_NO_EXPORT __attribute__ ((visibility("hidden")))
+#define TDE_EXPORT __attribute__ ((visibility("default")))
#elif defined(TQ_WS_WIN)
-#define KDE_NO_EXPORT
-#define KDE_EXPORT __declspec(dllexport)
+#define TDE_NO_EXPORT
+#define TDE_EXPORT __declspec(dllexport)
#else
-#define KDE_NO_EXPORT
-#define KDE_EXPORT
+#define TDE_NO_EXPORT
+#define TDE_EXPORT
#endif
+#define KDE_NO_EXPORT TDE_NO_EXPORT
+#define KDE_EXPORT TDE_EXPORT
+
/**
* KDE_Q_EXPORT_PLUGIN is a workaround for Qt not being able to
* cope with symbol visibility.
*/
#define KDE_Q_EXPORT_PLUGIN(PLUGIN) \
- TQ_EXTERN_C KDE_EXPORT const char* qt_ucm_query_verification_data(); \
- TQ_EXTERN_C KDE_EXPORT TQUnknownInterface* ucm_instantiate(); \
+ TQ_EXTERN_C TDE_EXPORT const char* qt_ucm_query_verification_data(); \
+ TQ_EXTERN_C TDE_EXPORT TQUnknownInterface* ucm_instantiate(); \
TQ_EXPORT_PLUGIN(PLUGIN)
/**
@@ -25,7 +25,7 @@
#cmakedefine __KDE_HAVE_GCC_VISIBILITY 1
/**
- * The KDE_NO_EXPORT macro marks the symbol of the given variable
+ * The TDE_NO_EXPORT macro marks the symbol of the given variable
* to be hidden. A hidden symbol is stripped during the linking step,
* so it can't be used from outside the resulting library, which is similar